// Copyright  2010 Nokia Corporation. All rights reserved. Nokia and Nokia Connecting People
// are registered trademarks of Nokia Corporation. Java and all Java-based marks are trademarks
// or registered trademarks of Sun Microsystems, Inc. Other product and company names mentioned
// herein may be trademarks or trade names of their respective owners.
//
//Subject to the conditions below, you may, without charge:
// * Use, copy, modify and/or merge copies of this software and associated documentation files (the Software)
// * Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
//
// This license, unmodified, shall be included with all copies or substantial portions of
// the Software that are distributed in source code form.
//
// The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
//
// Any person dealing with the Software shall not misrepresent the source of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import javax.microedition.lcdui.game.*;

class Field extends TiledLayer {
    private static final int WIDTH_IN_TILES = 12;
    private static final int HEIGHT_IN_TILES = 12;
    private static final int TILE_WIDTH = 16;
    private static final int TILE_HEIGHT = 16;

    private static int[][] cellTiles =
        {{-3, -2, -3, -1, -2, -1, -3, -1, -2, -3, -1, -2},
         {-2,  3,  4,  3,  1,  2,  3,  2,  1,  5,  2, -3},
         {-1,  2,  1,  2,  3,  4,  5,  3,  2,  4,  3, -1},
         {-2,  1,  4,  9,  9,  9,  9,  4,  5,  2,  1, -2},
         {-3,  3,  5,  9, 10, 10, 10,  2,  1,  3,  5, -1},
         {-2,  2,  3,  9, 10, 10, 10,  5,  4,  2,  1, -3},
         {-1,  4,  2,  9,  9,  9,  9,  3,  1,  3,  2, -2},
         {-3,  2,  5,  1,  3,  1,  4,  2,  5,  4,  3, -3},
         {-2,  1,  4,  2,  5,  2,  3,  4,  2,  1,  2, -1},
         {-1,  5,  1,  4,  3,  4,  1,  2,  3,  4,  1, -2},
         {-3,  2,  4,  5,  2,  3,  2,  4,  1,  2,  3, -3},
         {-2, -3, -2, -1, -2, -1, -3, -2, -1, -3, -1, -2}};
    private static int FOLD_TILE = 10;
    private static int FENCE_TILE = 9;
    private static int[][] waterFrames = {{6, 7, 8}, {7, 8, 6}, {8, 6, 7}};
    private int tickCount = 0;

    Field() {
        super(WIDTH_IN_TILES, HEIGHT_IN_TILES, SheepdogMIDlet.createImage("/field.png"),
              TILE_WIDTH, TILE_HEIGHT);

        createAnimatedTile(waterFrames[0][0]);      // tile -1
        createAnimatedTile(waterFrames[1][0]);      // tile -2
        createAnimatedTile(waterFrames[2][0]);      // tile -3

        for (int row = 0; row < HEIGHT_IN_TILES; ++row) {
            for (int column = 0; column < WIDTH_IN_TILES; ++column) {
                setCell(column, row, cellTiles[row][column]);
            }
        }
    }

    int getSheepdogStartX() {
        return getWidth() - 50;
    }


    int getSheepdogStartY() {
        return getHeight() - 50;
    }


    void tick() {
        int tickState = (tickCount++ >> 3);   // slow down x8
        int tile = tickState % 3;
        setAnimatedTile(-1 - tile, waterFrames[tile][(tickState % 9) / 3]);
    }


    // return true if any part of the rectangle overlaps a water tile
    // or the fence
    boolean containsImpassableArea(int x, int y, int width, int height) {
        int rowMin = y / TILE_HEIGHT;
        int rowMax = (y + height - 1) / TILE_HEIGHT;
        int columnMin = x / TILE_WIDTH;
        int columnMax = (x + width - 1) / TILE_WIDTH;

        for (int row = rowMin; row <= rowMax; ++row) {
            for (int column = columnMin; column <= columnMax; ++column) {
                int cell = getCell(column, row);
                if ((cell < 0) || (cell == FENCE_TILE)) {
                    return true;
                }
            }
        }
        return false;
    }

    // returns true if every pixel of the sprite is in the fold
    boolean inFold(Sprite s) {
        // we can assume that the sprite's reference pixel is unchanged
        int rowMin = s.getY() / TILE_HEIGHT;
        int rowMax = (s.getY() + s.getHeight() - 1) / TILE_HEIGHT;
        int columnMin = s.getX() / TILE_WIDTH;
        int columnMax = (s.getX() + s.getWidth() - 1) / TILE_WIDTH;

        for (int row = rowMin; row <= rowMax; ++row) {
            for (int column = columnMin; column <= columnMax; ++column) {
                if (getCell(column, row) != FOLD_TILE) {
                    return false;
                }
            }
        }
        return true;
    }
}
