// Copyright  2010 Nokia Corporation. All rights reserved. Nokia and Nokia Connecting People
// are registered trademarks of Nokia Corporation. Java and all Java-based marks are trademarks
// or registered trademarks of Sun Microsystems, Inc. Other product and company names mentioned
// herein may be trademarks or trade names of their respective owners.
//
//Subject to the conditions below, you may, without charge:
// * Use, copy, modify and/or merge copies of this software and associated documentation files (the Software)
// * Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
//
// This license, unmodified, shall be included with all copies or substantial portions of
// the Software that are distributed in source code form.
//
// The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
//
// Any person dealing with the Software shall not misrepresent the source of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import javax.microedition.lcdui.*;

class MenuList extends List implements CommandListener {
    private SheepdogMIDlet midlet;
    private Command exitCommand;
    private boolean gameActive = false;

    MenuList(SheepdogMIDlet midlet) {
        super("Sheepdog", List.IMPLICIT);
        this.midlet = midlet;
        append("New game", null);
        append("High score", null);
        append("Instructions", null);
        append("Settings", null);
        exitCommand = new Command("Exit", Command.EXIT, 1);
        addCommand(exitCommand);
        setCommandListener(this);
    }

    void setGameActive(boolean active) {
        if (active && !gameActive) {
            gameActive = true;
            insert(0, "Continue", null);
        }
        else if (!active && gameActive) {
            gameActive = false;
            delete(0);
        }
    }

    public void commandAction(Command c, Displayable d) {
        if (c == List.SELECT_COMMAND) {
            int index = getSelectedIndex();
            if (index != -1) { // should never be -1
                if (!gameActive) {
                    index++;
                }
                switch (index) {
                case 0:     // Continue
                    midlet.menuListContinue();
                    break;
                case 1:     // New game
                    midlet.menuListNewGame();
                    break;
                case 2:     // High score
                    midlet.menuListHighScore();
                    break;
                case 3:     // Instructions
                    midlet.menuListInstructions();
                    break;
                case 4:     // Settings
                    midlet.menuListSettings();
                    break;
                default:
                    // can't happen
                    break;
                }
            }
        }
        else if (c == exitCommand) {
            midlet.menuListQuit();
        }
    }
}
