// Copyright  2010 Nokia Corporation. All rights reserved. Nokia and Nokia Connecting People
// are registered trademarks of Nokia Corporation. Java and all Java-based marks are trademarks
// or registered trademarks of Sun Microsystems, Inc. Other product and company names mentioned
// herein may be trademarks or trade names of their respective owners.
//
//Subject to the conditions below, you may, without charge:
// * Use, copy, modify and/or merge copies of this software and associated documentation files (the Software)
// * Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
//
// This license, unmodified, shall be included with all copies or substantial portions of
// the Software that are distributed in source code form.
//
// The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
//
// Any person dealing with the Software shall not misrepresent the source of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import javax.microedition.lcdui.*;

class SplashScreen extends Canvas implements Runnable {
    private final SheepdogMIDlet midlet;
    private Image splashImage;
    private volatile boolean dismissed = false;

    SplashScreen(SheepdogMIDlet midlet) {
        this.midlet = midlet;
        setFullScreenMode(true);
        splashImage = SheepdogMIDlet.createImage("/splash.png");
        new Thread(this).start();
    }

    public void run() {
        synchronized(this) {
            try {
                wait(3000L);   // 3 seconds
            }
            catch (InterruptedException e) {
                // can't happen in MIDP: no Thread.interrupt method
            }
            dismiss();
        }
    }

    public void paint(Graphics g) {
        int width = getWidth();
        int height = getHeight();
        g.setColor(0x00FFFFFF);  // white
        g.fillRect(0, 0, width, height);

        g.setColor(0x00FF0000);  // red
        g.drawRect(1, 1, width-3, height-3);  // red border one pixel from edge

        if (splashImage != null) {
            g.drawImage(splashImage, width/2, height/2, Graphics.VCENTER | Graphics.HCENTER);
            splashImage = null;
            midlet.splashScreenPainted();
        }
    }

    public synchronized void keyPressed(int keyCode) {
        dismiss();
    }

    private void dismiss() {
        if (!dismissed) {
            dismissed = true;
            midlet.splashScreenDone();
        }
    }
}
