// Copyright  2010 Nokia Corporation. All rights reserved. Nokia and Nokia Connecting People
// are registered trademarks of Nokia Corporation. Java and all Java-based marks are trademarks
// or registered trademarks of Sun Microsystems, Inc. Other product and company names mentioned
// herein may be trademarks or trade names of their respective owners.
//
//Subject to the conditions below, you may, without charge:
// * Use, copy, modify and/or merge copies of this software and associated documentation files (the Software)
// * Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
//
// This license, unmodified, shall be included with all copies or substantial portions of
// the Software that are distributed in source code form.
//
// The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
//
// Any person dealing with the Software shall not misrepresent the source of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import javax.microedition.media.*;
import java.io.*;

class SoundEffects {
    private static SoundEffects instance;
    private Player sheepSoundPlayer;
    private Player dogSoundPlayer;

    private SoundEffects() {
        sheepSoundPlayer = createPlayer("/sheep.wav", "audio/x-wav");
        dogSoundPlayer = createPlayer("/dog.wav", "audio/x-wav");
    }

    static SoundEffects getInstance() {
        if (instance == null) {
            instance = new SoundEffects();
        }
        return instance;
    }

    void startSheepSound() {
        startPlayer(sheepSoundPlayer);
    }

    void startDogSound() {
        startPlayer(dogSoundPlayer);
    }

    void startGameOverSound() {
        startPlayer(createPlayer("/gameover.mid", "audio/midi"));
    }

    void startHighScoreSound() {
        startPlayer(createPlayer("/highscore.mid", "audio/midi"));
    }

    private void startPlayer(Player p) {
        if (p != null) {
            try {
                p.stop();
                p.setMediaTime(0L);
                p.start();
            }
            catch (MediaException me) {
                // ignore
            }
        }
    }

    private Player createPlayer(String filename, String format) {
        Player p = null;
        try {
            InputStream is = getClass().getResourceAsStream(filename);
            p = Manager.createPlayer(is, format);
            p.prefetch();
        }
        catch (IOException ioe) {
            // ignore
        }
        catch (MediaException me) {
            // ignore
        }
        return p;
    }
}
